@@ -23,7 +23,13 @@
 #include <QObject>
 #include <QVariantAnimation>
 
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ActionReply>
+#include <KAuth/HelperSupport>
+#else
 #include <KAuth>
+#endif
 
 using namespace KAuth;
 
@@ -45,12 +51,16 @@ private:
     int readBrightness() const;
     bool writeBrightness(int brightness) const;
 
+    int readFromDevice(const QString &device, const QString &property) const;
+    bool writeToDevice(const QString &device, int brightness) const;
+
     /**
      * The kernel offer from version 2.6.37 the type of the interface, and based on that
      * we can decide which interface is better for us, being the order
      * firmware-platform-raw
      */
     void initUsingBacklightType();
+    QStringList getBacklightTypeDevices() const;
 
     /**
      * FreeBSD (and other BSDs) can control backlight via acpi_video(4)
@@ -58,9 +68,9 @@ private:
     void initUsingSysctl();
 
     bool m_isSupported = false;
-    QString m_dirname;
     QString m_sysctlDevice;
     QList<int> m_sysctlBrightnessLevels;
+    QList<QPair<QString /*device path*/, int /*max brightness*/>> m_devices;
 
     QVariantAnimation m_anim;
 };
