@@ -32,8 +32,14 @@
 #include <QPropertyAnimation>
 #include <QTimer>
 
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/Action>
+#include <KAuth/ExecuteJob>
+#else
 #include <KAuthAction>
 #include <KAuthExecuteJob>
+#endif
 #include <KPluginFactory>
 #include <KSharedConfig>
 
